/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.interfaces;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.services.IPrototypeService.Prototype;

/**
 * Interface for compositors, i.e. classes which know how to compose
 * {@link EObject}s.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 75F650B0058B591BE903CC45C0AB9876
 */
public interface ICompositor<T extends EObject> extends IEObjectAware<T> {
	/**
	 * Returns whether the given container may include the given contained
	 * object.
	 */
	boolean canCompose(T container, EObject contained,
			ICompositionContext context);

	/**
	 * Asks the compositor to insert the contained object into the container.
	 * The contained object may be modified (i.e. renamed, etc.) if necessary.
	 * This method returns a boolean, since user-interaction during compose
	 * might cancel the command.
	 */
	boolean compose(T container, EObject contained, ICompositionContext context);

	/**
	 * Returns whether this compositor is able to compose the given prototype.
	 * While {@link #canCompose(EObject, EObject, ICompositionContext)}
	 * considers a concrete composition between the container and contained
	 * element, this method returns this compositor's ability to accept the
	 * given prototype in general.
	 */
	boolean canComposePrototype(Prototype prototype);
}
