/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.interfaces;

/**
 * This interface describes a constraint violation produced by some constraint
 * checker. A constraint violation has a severity, an explanation and possibly a
 * quick fix.
 * 
 * @author hoelzlf
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: BAED4776E8F47E7A6D42A7D38A68FAA6
 */
public interface IConstraintViolation {

	/** Returns the severity of the constraint violation. */
	ESeverity getSeverity();

	/** Returns the explanation of the constraint violation. */
	String getExplanation();

	/** Returns the quick fix handler for this constraint violation. */
	IQuickFixHandler getQuickFixHandler();

	/** Enumeration of severity classes. */
	public static enum ESeverity {
		/** Fatal error severity. */
		FATAL,
		/** Normal error severity. */
		ERROR,
		/** Warning severity. */
		WARNING,
		/** Information severity. */
		INFO,
		/** Debug severity. */
		DEBUG
	}

	/** Interface for quick fix handlers. */
	public static interface IQuickFixHandler {
		/** Applies the quick fix. */
		void applyQuickFix();
	}
}
